import { T as ThemeInput, L as LanguageInput, C as CodeToHtmlOptions } from './chunks/types.js';

/*---------------------------------------------------------
 * Copyright (C) Microsoft Corporation. All rights reserved.
 *--------------------------------------------------------*/

interface WebAssemblyInstantiator {
	(importObject: Record<string, Record<string, WebAssembly.ImportValue>> | undefined): Promise<WebAssembly.WebAssemblyInstantiatedSource>;
}
interface ICommonOptions {
	print?(str: string): void;
}
interface IInstantiatorOptions extends ICommonOptions {
	instantiator: WebAssemblyInstantiator;
}
interface IDataOptions extends ICommonOptions {
	data: ArrayBuffer | Response;
}
type IOptions = IInstantiatorOptions | IDataOptions;

interface CoreHighlighterOptions {
    themes: ThemeInput[];
    langs: LanguageInput[];
    getOnigurumaWasm: () => Promise<IOptions>;
}
declare function getHighlighter(options: CoreHighlighterOptions): Promise<{
    codeToThemedTokens: (code: string, lang?: string, theme?: string, options?: {
        includeExplanation: boolean;
    }) => {
        content: string;
    }[][];
    codeToHtml: (code: string, options?: CodeToHtmlOptions) => string;
}>;

export { CoreHighlighterOptions, getHighlighter };
